<?php
/**
 * Silver Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/featured-posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/promo.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/instagram.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/misc.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';

/**
 * Custom customizer functions.
 */
function silver_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'silver_design', array(
		'title'       => esc_html__( 'Design', 'silver' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'silver' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'silver_options', array(
		'title'       => esc_html__( 'Theme Options', 'silver' ),
		'description' => esc_html__( 'This panel is used for customizing the Silver theme.', 'silver' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'silver_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'silver_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Static Front Page section.
	$wp_customize->get_section( 'static_front_page' )->panel    = 'silver_design';
	$wp_customize->get_section( 'static_front_page' )->priority = 9;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'silver_design';
	$wp_customize->get_section( 'custom_css' )->priority = 11;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'silver' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

}
add_action( 'customize_register', 'silver_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function silver_customize_preview_js() {
	wp_enqueue_script( 'silver-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'silver_customize_preview_js' );

/**
 * Custom styles.
 */
function silver_custom_css() {

	// Set up empty variable.
	$css = '';

	// Get the customizer value.
	$color = get_theme_mod( 'silver-accent-colors', '#ff9999' );

	if ( $color != '#ff9999' ) {
		$css .= '
		.featured-box-title,
		.text-dark a.tag-link,
		.text-light a.tag-link,
		.button {
			background-color: ' . sanitize_hex_color( $color ) . ';
		}

		.slider-collage .slide-content {
			background-color: ' . silver_hex2rgba( $color, 0.85 ) . ';
		}

		.widget-title:before,
		.indexpage-title:after {
			background: linear-gradient(to right, ' . $color . ' 2.3rem, #efefef 2.3rem, #efefef 100%);
		}

		.text-dark a:hover .share-btn,
		.text-light a:hover .share-btn,
		.text-dark .share-btn:hover,
		.text-light .share-btn:hover {
			background-color: ' . silver_hex2rgba( $color, 0.8 ) . ';
		}
		';
	}

	// Print the custom style
	wp_add_inline_style( 'silver-style', $css );

}
add_action( 'wp_enqueue_scripts', 'silver_custom_css' );

/**
 * Display theme documentation on customizer page.
 */
function silver_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'silver-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'silver-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/silver/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'silver' ),
		)
	);

}
add_action( 'customize_controls_enqueue_scripts', 'silver_documentation_link' );

/**
 * Custom RSS feed url.
 */
function silver_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'silver-custom-rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'silver_custom_rss_url', 10, 2 );

/**
 * Retrieve tags list.
 */
function silver_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = esc_html__( 'Select a tag &hellip;', 'silver' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function silver_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function silver_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}

/**
 * Sanitize the featured posts order value.
 */
function silver_sanitize_featured_orderby( $order ) {
	if ( ! in_array( $order, array( 'date', 'rand' ) ) ) {
		$order = 'date';
	}
	return $order;
}
